@@ -279,7 +279,11 @@ def create_parser(frontends, backends):
                               help='Suppress all logging output')
     parser_package.add_argument('-r', '--recursive', action='store_true',
                                 help='Recursively package requirements'),
-    parser_package.add_argument('package', help='Name of the package')
+    parser_package.add_argument('-c', '--color', action='store_true',
+                                help='Show colored logging output'),
+    parser_package.add_argument('package', help='Name of the package. '
+                                                'Use <package>@<version> to '
+                                                'package a specific version.')
 
     return parser
 
@@ -301,13 +305,14 @@ def _get_installed_backends():
     return _get_installed_plugins('upt.backends')
 
 
-def package(pkg_name, frontend, backend, output, recursive, packaged=[]):
+def package(pkg_name, version, frontend, backend, output, recursive,
+            packaged=[]):
     logger = logging.getLogger('upt')
 
     try:
         upt_pkg = None
         upt.log.logger_set_formatter(logger, 'Frontend')
-        upt_pkg = frontend.parse(pkg_name)
+        upt_pkg = frontend.parse(pkg_name, version)
         upt_pkg.frontend = frontend.name
         upt.log.logger_set_formatter(logger, 'Backend')
         backend.create_package(upt_pkg, output=output)
@@ -320,12 +325,13 @@ def package(pkg_name, frontend, backend, output, recursive, packaged=[]):
                         continue
 
                     if backend.needs_requirement(requirement, phase):
-                        package(requirement.name, frontend, backend,
+                        package(requirement.name, None, frontend, backend,
                                 output, recursive, packaged)
     except upt.exceptions.UnhandledFrontendError as e:
         print(e, file=sys.stderr)
         sys.exit(1)
-    except upt.exceptions.InvalidPackageNameError as e:
+    except (upt.exceptions.InvalidPackageNameError,
+            upt.exceptions.InvalidPackageVersionError) as e:
         print(e, file=sys.stderr)
         sys.exit(1)
     finally:
@@ -334,6 +340,14 @@ def package(pkg_name, frontend, backend, output, recursive, packaged=[]):
             upt_pkg._clean()
 
 
+def _extract_name_version_from_package(package):
+    try:
+        name, version = package.split('@')
+    except ValueError:
+        name, version = package, None
+    return name, version or None
+
+
 def main():
     frontends = _get_installed_frontends()
     backends = _get_installed_backends()
@@ -373,5 +387,6 @@ def main():
         # values for us.
         frontend = frontends[args.frontend]()
         backend = backends[args.backend]()
-        upt.log.create_logger(args.log_level)
-        package(args.package, frontend, backend, args.output, args.recursive)
+        name, version = _extract_name_version_from_package(args.package)
+        upt.log.create_logger(args.log_level, args.color)
+        package(name, version, frontend, backend, args.output, args.recursive)
